@@ -140,12 +140,12 @@ pub const ERR_NO_PARAMS: &str = "action params not specified";
 
 #[inline]
 pub fn format_action_topic(oid: &OID) -> String {
-    format!("{}{}", ACTION_TOPIC, oid.to_path())
+    format!("{}{}", ACTION_TOPIC, oid.as_path())
 }
 
 #[inline]
 pub fn format_raw_state_topic(oid: &OID) -> String {
-    format!("{}{}", RAW_STATE_TOPIC, oid.to_path())
+    format!("{}{}", RAW_STATE_TOPIC, oid.as_path())
 }
 
 #[derive(Deserialize)]
